==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/InstanceReferenceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.InstanceReference;
import io.ciera.tool.sql.ooaofooa.value.InstanceReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class InstanceReferenceSetImpl extends InstanceSet<InstanceReferenceSet,InstanceReference> implements InstanceReferenceSet {

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( InstanceReference instancereference : this ) instancereference.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( InstanceReference instancereference : this ) instancereference.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( InstanceReference instancereference : this ) valueset.add( instancereference.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public V_VARSet R808_refers_to_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( InstanceReference instancereference : this ) v_varset.add( instancereference.R808_refers_to_V_VAR() );
        return v_varset;
    }


    @Override
    public InstanceReference nullElement() {
        return InstanceReferenceImpl.EMPTY_INSTANCEREFERENCE;
    }

    @Override
    public InstanceReferenceSet emptySet() {
      return new InstanceReferenceSetImpl();
    }

    @Override
    public InstanceReferenceSet value() {
        return this;
    }

    @Override
    public List<InstanceReference> elements() {
        return Arrays.asList(toArray(new InstanceReference[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/InstanceReferenceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.InstanceReference;
import io.ciera.tool.sql.ooaofooa.value.InstanceReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InstanceReferenceSetImpl extends InstanceSet<InstanceReferenceSet,InstanceReference> implements InstanceReferenceSet {

    public InstanceReferenceSetImpl() {
    }

    public InstanceReferenceSetImpl(Comparator<? super InstanceReference> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( InstanceReference instancereference : this ) instancereference.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( InstanceReference instancereference : this ) instancereference.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( InstanceReference instancereference : this ) valueset.add( instancereference.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public V_VARSet R808_refers_to_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( InstanceReference instancereference : this ) v_varset.add( instancereference.R808_refers_to_V_VAR() );
        return v_varset;
    }


    @Override
    public InstanceReference nullElement() {
        return InstanceReferenceImpl.EMPTY_INSTANCEREFERENCE;
    }

    @Override
    public InstanceReferenceSet emptySet() {
      return new InstanceReferenceSetImpl();
    }

    @Override
    public InstanceReferenceSet emptySet(Comparator<? super InstanceReference> comp) {
      return new InstanceReferenceSetImpl(comp);
    }

    @Override
    public InstanceReferenceSet value() {
        return this;
    }

    @Override
    public List<InstanceReference> elements() {
        return Arrays.asList(toArray(new InstanceReference[0]));
    }

}
